@@ -1,4 +1,5 @@
 from datetime import datetime, date, timedelta
+from uuid import UUID
 
 
 class EWAHConstants:
@@ -79,10 +80,11 @@ class EWAHConstants:
             datetime: "timestamp with time zone",
             date: "date",
             timedelta: "interval",
+            UUID: "text",
         },
         DWH_ENGINE_SNOWFLAKE: {
-            str: "VARCHAR",
-            int: "INTEGER",
+            str: "TEXT",
+            int: "FLOAT",  # Temporary fix - need to implement dynamic data type changes
             float: "FLOAT",
             dict: "OBJECT",
             list: "ARRAY",
@@ -92,6 +94,7 @@ class EWAHConstants:
             bool: "BOOLEAN",
             datetime: "TIMESTAMP_TZ",
             date: "DATE",
+            UUID: "TEXT",
         },
         DWH_ENGINE_BIGQUERY: {
             str: "STRING",
@@ -108,6 +111,7 @@ class EWAHConstants:
             datetime: "TIMESTAMP",
             date: "DATE",
             bytes: "BYTES",
+            UUID: "STRING",
         },
         # DWH_ENGINE_REDSHIFT: {},
         # DWH_ENGINE_S3: {},
@@ -124,5 +128,6 @@ class EWAHConstants:
             bool: "x",
             datetime: "timestamp with time x",
             date: "x",
+            UUID: "x",
         },
     }
