@@ -25,7 +25,7 @@ def dag_factory_atomic(
     target_schema_suffix: str = "_next",
     target_database_name: Optional[str] = None,
     default_args: Optional[dict] = None,
-    schedule_interval: Union[str, timedelta] = timedelta(days=1),
+    schedule_interval: Optional[Union[str, timedelta]] = timedelta(days=1),
     end_date: Optional[datetime] = None,
     read_right_users: Optional[Union[List[str], str]] = None,
     additional_dag_args: Optional[dict] = None,
@@ -53,17 +53,16 @@ def dag_factory_atomic(
         if not isinstance(read_right_users, Iterable):
             raise_exception("read_right_users must be an iterable or string!")
 
+    # Initialize parameter with default value here that can be updated depending
+    # on schedule_interval conditions
+    catchup = False
+
+    # Allow using cron-style schedule intervals
     if isinstance(schedule_interval, str):
-        # Allow using cron-style schedule intervals
-        catchup = False
         assert croniter.is_valid(
             schedule_interval
-        ), "schedule_interval is neither timedelta nor not valid cron!"
-    else:
-        assert isinstance(
-            schedule_interval, timedelta
-        ), "schedule_interval must be cron-string or timedelta!"
-
+        ), "schedule_interval is not valid a cron expression!"
+    elif isinstance(schedule_interval, timedelta):
         catchup = True
         # fake catchup = True: between start_date and end_date is one schedule_interval
         # --> run the full refreshs every schedule_interval at the same time instead of
@@ -95,9 +94,16 @@ def dag_factory_atomic(
         assert isinstance(dagrun_timeout_factor, (int, float)) and (
             0 < dagrun_timeout_factor <= 1
         ), _msg
-        additional_dag_args["dagrun_timeout"] = additional_dag_args.get(
-            "dagrun_timeout", dagrun_timeout_factor * schedule_interval
-        )
+        # If schedule_interval is a string, we assume it is a cron and set a default
+        if isinstance(schedule_interval, str):
+            default_timeout = timedelta(hours=1)
+            additional_dag_args["dagrun_timeout"] = additional_dag_args.get(
+              "dagrun_timeout", default_timeout
+            )
+        else:
+          additional_dag_args["dagrun_timeout"] = additional_dag_args.get(
+              "dagrun_timeout", dagrun_timeout_factor * schedule_interval
+          )
 
     if task_timeout_factor:
         additional_task_args["execution_timeout"] = additional_task_args.get(
