@@ -6,7 +6,7 @@ from ewah.utils.dbt_operator import EWAHdbtOperator
 
 from croniter import croniter
 from datetime import datetime, timedelta
-from typing import Union
+from typing import Optional, Union
 
 import pytz
 
@@ -25,7 +25,8 @@ def dbt_dags_factory(
     schema_name="analytics",  # see https://docs.getdbt.com/dbt-cli/configure-your-profile/#understanding-target-schemas
     keepalives_idle=0,  # see https://docs.getdbt.com/reference/warehouse-profiles/postgres-profile/
     dag_base_name="T_dbt_run",
-    schedule_interval: Union[str, timedelta] = timedelta(hours=1),
+    schedule_interval: Optional[Union[str, timedelta]] = timedelta(days=1),
+    full_refresh_schedule_interval: Optional[Union[str, timedelta]] = None,
     start_date=datetime(2019, 1, 1),
     default_args=None,
     run_flags=None,  # e.g. --model tag:base
@@ -47,14 +48,19 @@ def dbt_dags_factory(
         EC.DWH_ENGINE_BIGQUERY,
     )
 
+    # Initialize parameters with default values here that can be updated depending
+    # on schedule_interval conditions
+    catchup = False
+    end_date = None
+    # Keep original start_date for full refresh DAG
+    full_refresh_start_date = start_date
+
+    # Allow using cron-style schedule intervals
     if isinstance(schedule_interval, str):
-        # Allow using cron-style schedule intervals
         assert croniter.is_valid(
             schedule_interval
-        ), "schedule_interval is neither timedelta nor not valid cron!"
-        catchup = False
-        end_date = None
-    else:
+        ), "schedule_interval is not valid a cron expression!"
+    elif isinstance(schedule_interval, timedelta):
         # if start_date is timezone offset-naive, assume utc and turn into offset-aware
         catchup = True
         if not start_date.tzinfo:
@@ -97,7 +103,10 @@ def dbt_dags_factory(
         dagrun_timeout=dagrun_timeout,
         **dag_kwargs,
     )
-    dag_2 = DAG(dag_base_name + "_full_refresh", schedule_interval=None, **dag_kwargs)
+    # for full refresh we need to set the original start_date
+    dag_kwargs["start_date"] = full_refresh_start_date
+    dag_kwargs["catchup"] = False # dont catch up full refreshes
+    dag_2 = DAG(dag_base_name + "_full_refresh", schedule_interval=full_refresh_schedule_interval, **dag_kwargs)
 
     sensor_sql = """
         SELECT
@@ -205,7 +214,7 @@ def dbt_snapshot_dag(
     schema_name="analytics",  # for the profiles.yml
     keepalives_idle=0,
     dag_name="T_dbt_snapshots",
-    schedule_interval: Union[str, timedelta] = timedelta(hours=1),
+    schedule_interval: Optional[Union[str, timedelta]] = timedelta(hours=1),
     start_date=None,
     default_args=None,
     dagrun_timeout_factor=None,
