@@ -11,7 +11,6 @@ from time import sleep
 
 
 class EWAHHubspotHook(EWAHBaseHook):
-
     _ATTR_RELABEL = {
         "api_key": "password",
     }
@@ -25,6 +24,8 @@ class EWAHHubspotHook(EWAHBaseHook):
     PROPERTIES_URL = "https://api.hubapi.com/crm/v3/properties/{0}"
     PIPELINES_URL = "https://api.hubapi.com/crm/v3/pipelines/{0}"
     ASSOC_URL = "https://api.hubapi.com/crm/v3/associations/{fromObjectType}/{toObjectType}/batch/read"
+    # ASSOC_URL_V4 is only used for a custom object of a customer
+    ASSOC_URL_V4 = "https://api.hubapi.com/crm/v4/associations/{fromObjectType}/{toObjectType}/batch/read"
     OWNERS_URL = "https://api.hubapi.com/crm/v3/owners/"
 
     # The value is a list of possible associations. Giving the "all" value for
@@ -120,6 +121,13 @@ class EWAHHubspotHook(EWAHBaseHook):
             "tickets",
             "quotes",
         ],
+        # Custom object requested by a customer. This is not a standard object in HubSpot.
+        "p3909618_milestones": [
+            "companies",
+            "contacts",
+            "deals",
+            "p3909618_milestones",
+        ],
     }
 
     @staticmethod
@@ -136,8 +144,11 @@ class EWAHHubspotHook(EWAHBaseHook):
             return []
         request = requests.get(
             url=self.PROPERTIES_URL.format(object),
-            params={"hapikey": self.conn.api_key},
-            headers={"accept": "application/json"},
+            params={},
+            headers={
+                "accept": "application/json",
+                "authorization": "Bearer {0}".format(self.conn.api_key),
+            },
         )
         assert request.status_code == 200, request.text
         return [property["name"] for property in request.json()["results"]]
@@ -178,10 +189,8 @@ class EWAHHubspotHook(EWAHBaseHook):
         max_properties_per_call: int = 250,
         batch_size: int = 10000,
     ) -> List[Dict[str, Any]]:
-
         self.log.info("Loading data for CRM object {0}!".format(object))
-        params_auth = {"hapikey": self.conn.api_key}
-        params_object = {"hapikey": self.conn.api_key, "limit": 100}
+        params_object = {"limit": 100}
         if associations == "all":
             # Resolve the "all" special keyword
             associations = self.ACCEPTED_OBJECTS.get(object, [])
@@ -209,7 +218,7 @@ class EWAHHubspotHook(EWAHBaseHook):
                 ]
             elif object == "pipelines":
                 url_object_raw = self.PIPELINES_URL
-                object_list = ["tickets", "deals"]
+                object_list = ["tickets", "deals", "p3909618_milestones"]
 
             params_object["objectType"] = object_list.pop(0)
             url_object = url_object_raw.format(params_object["objectType"])
@@ -238,6 +247,13 @@ class EWAHHubspotHook(EWAHBaseHook):
                         "\n\t- ".join(associations)
                     )
                 )
+                if object == "p3909618_milestones":
+                    # The custom object needs the v4 API for the right associations
+                    assoc_url = self.ASSOC_URL_V4
+                    self.log.info("Using v4 API for associations")
+                else:
+                    assoc_url = self.ASSOC_URL
+                    self.log.info("Using v3 API for associations")
 
         keepgoing = True
         i = 0
@@ -250,7 +266,10 @@ class EWAHHubspotHook(EWAHBaseHook):
             request = self.retry_request(
                 url=url_object,
                 params=params_object,
-                headers={"accept": "application/json"},
+                headers={
+                    "accept": "application/json",
+                    "authorization": "Bearer {0}".format(self.conn.api_key),
+                },
                 expected_status_code=200,
                 retries=3,
             )
@@ -278,14 +297,14 @@ class EWAHHubspotHook(EWAHBaseHook):
                 )
                 for association in associations:
                     request = requests.post(
-                        self.ASSOC_URL.format(
+                        assoc_url.format(
                             fromObjectType=object,
                             toObjectType=association,
                         ),
-                        params=params_auth,
                         headers={
                             "accept": "application/json",
                             "content-type": "application/json",
+                            "authorization": "Bearer {0}".format(self.conn.api_key),
                         },
                         data=payload,
                     )
