@@ -11,7 +11,6 @@ from cryptography.fernet import Fernet
 
 
 class EWAHPlentyMarketsHook(EWAHBaseHook):
-
     _ATTR_RELABEL = {
         "username": "login",
         "url": "host",
@@ -24,6 +23,8 @@ class EWAHPlentyMarketsHook(EWAHBaseHook):
 
     _INCREMENTAL_FIELDS = {
         "/rest/orders": ["updatedAtFrom", "updatedAtTo"],
+        "/rest/orders/search": ["updatedAt", "updatedAt"],
+        # Only added so EWAH does not fail to find incremental fields for this endpoint
         "/rest/orders/status-history": ["createdAtFrom", "createdAtTo"],
         "/rest/accounts/contacts": ["updatedAtAfter", "updatedAtBefore"],
         # TODO - refactor this hook to not need this dict to begin with
@@ -59,6 +60,7 @@ class EWAHPlentyMarketsHook(EWAHBaseHook):
         "/rest/orders/documents/proFormaInvoice": ["updatedAtFrom", "updatedAtTo"],
         "/rest/orders/documents/reorder": ["updatedAtFrom", "updatedAtTo"],
         "/rest/orders/documents/uploaded": ["updatedAtFrom", "updatedAtTo"],
+        "/rest/audit-log/search": ["versionFrom", "versionTo"],
     }
 
     @staticmethod
@@ -188,6 +190,17 @@ class EWAHPlentyMarketsHook(EWAHBaseHook):
             resource = "/rest/{0}".format(resource)
         return resource
 
+    @staticmethod
+    def request_wrapper(url, params, headers, method="get", payload=None):
+        if method == "get":
+            r = requests.get(url, headers=headers, params=params)
+        elif method == "post":
+            r = requests.post(url, headers=headers, params=params, json=payload)
+        else:
+            raise ValueError("Invalid method. Supported methods are 'get' and 'post'")
+
+        return r
+
     def get_data_in_batches(
         self,
         resource,
@@ -195,6 +208,8 @@ class EWAHPlentyMarketsHook(EWAHBaseHook):
         data_until=None,
         batch_size=10000,
         additional_params=None,
+        request_method=None,
+        post_request_payload=None,
     ):
         params = {
             "itemsPerPage": 250,  # Maximum
@@ -206,13 +221,37 @@ class EWAHPlentyMarketsHook(EWAHBaseHook):
         resource = self.format_resource(resource)
         url = self.endpoint + resource
 
-        if data_from:
-            params[self._INCREMENTAL_FIELDS[resource][0]] = data_from.isoformat()
-        if data_until:
-            if resource == "/rest/accounts/contacts":
-                # inconsistent API implementation - ignores data for last day otherwise
-                data_until += timedelta(days=1)
-            params[self._INCREMENTAL_FIELDS[resource][1]] = data_until.isoformat()
+        if resource == "/rest/orders/search":
+            if data_from and data_until:
+                params[
+                    "updatedAt"
+                ] = f"between:{data_from.isoformat()},{data_until.isoformat()}"
+            elif data_from:
+                params["updatedAt"] = f"gte:{data_from.isoformat()}"
+            elif data_until:
+                params["updatedAt"] = f"lte:{data_until.isoformat()}"
+        else:
+            if data_from:
+                if request_method == "get":
+                    params[
+                        self._INCREMENTAL_FIELDS[resource][0]
+                    ] = data_from.isoformat()
+                elif request_method == "post":
+                    post_request_payload[
+                        self._INCREMENTAL_FIELDS[resource][0]
+                    ] = data_from.isoformat()
+            if data_until:
+                if request_method == "get":
+                    if resource == "/rest/accounts/contacts":
+                        # inconsistent API implementation - ignores data for last day otherwise
+                        data_until += timedelta(days=1)
+                    params[
+                        self._INCREMENTAL_FIELDS[resource][1]
+                    ] = data_until.isoformat()
+                elif request_method == "post":
+                    post_request_payload[
+                        self._INCREMENTAL_FIELDS[resource][1]
+                    ] = data_until.isoformat()
 
         data = []
         while True:
@@ -222,7 +261,13 @@ class EWAHPlentyMarketsHook(EWAHBaseHook):
                 "Authorization": "Bearer {0}".format(self.token),
             }
             self.log.info("Requesting new page of data...")
-            data_request = requests.get(url, params=params, headers=headers)
+            data_request = self.request_wrapper(
+                url,
+                params=params,
+                headers=headers,
+                method=request_method,
+                payload=post_request_payload,
+            )
             assert data_request.status_code in (200, 401), "Status {0}: {1}".format(
                 data_request.status_code, data_request.text
             )
@@ -238,7 +283,13 @@ class EWAHPlentyMarketsHook(EWAHBaseHook):
                             url = self.endpoint + resource
                         else:
                             url = self.endpoint + "/rest/{0}".format(resource)
-                        data_request = requests.get(url, params=params, headers=headers)
+                        data_request = self.request_wrapper(
+                            url,
+                            params=params,
+                            headers=headers,
+                            method=request_method,
+                            payload=post_request_payload,
+                        )
                 except:
                     pass  # assert below will take care of any error
             assert data_request.status_code == 200, "Status {0}: {1}".format(
