@@ -4,7 +4,6 @@ from ewah.hooks.sharepoint import EWAHSharepointHook
 
 
 class EWAHSharepointOperator(EWAHBaseOperator):
-
     _NAMES = ["sharepoint"]
 
     _ACCEPTED_EXTRACT_STRATEGIES = {
@@ -20,23 +19,25 @@ class EWAHSharepointOperator(EWAHBaseOperator):
         sheet_name: str,
         header_row: int = 1,
         start_row: int = 2,
+        batch_size: int = 10000,
         *args,
         **kwargs,
     ) -> None:
-        assert file_relative_path.endswith(".xlsx"), "Only Excel files for now!"
+        assert file_relative_path.endswith((".xlsx", ".xlsm")), "Only Excel files for now!"
         self.file_relative_path = file_relative_path
         self.sheet_name = sheet_name
         self.header_row = header_row
         self.start_row = start_row
+        self.batch_size = batch_size
         super().__init__(*args, **kwargs)
 
     def ewah_execute(self, context: dict) -> None:
         self.log.info("Loading data...")
-        self.upload_data(
-            self.source_hook.get_data_from_excel(
-                self.file_relative_path,
-                self.sheet_name,
-                self.header_row,
-                self.start_row,
-            )
-        )
+        for batch in self.source_hook.get_data_from_excel(
+            self.file_relative_path,
+            self.sheet_name,
+            self.header_row,
+            self.start_row,
+            self.batch_size,
+        ):
+            self.upload_data(batch)
