@@ -2,6 +2,7 @@ from ewah.constants import EWAHConstants as EC
 from ewah.uploaders.snowflake import EWAHSnowflakeUploader
 from ewah.uploaders.postgres import EWAHPostgresUploader
 from ewah.uploaders.google_sheets import EWAHGSheetsUploader
+from ewah.uploaders.bigquery import EWAHBigQueryUploader
 
 
 def get_uploader(dwh_engine):
@@ -9,7 +10,7 @@ def get_uploader(dwh_engine):
         return {
             EC.DWH_ENGINE_POSTGRES: EWAHPostgresUploader,
             EC.DWH_ENGINE_SNOWFLAKE: EWAHSnowflakeUploader,
-            # DWH_ENGINE_BIGQUERY: bq_hook,
+            EC.DWH_ENGINE_BIGQUERY: EWAHBigQueryUploader,
             EC.DWH_ENGINE_GS: EWAHGSheetsUploader,
         }[dwh_engine]
     except KeyError:
